import { ReactFragment } from "react";
type Scalars = {
    GatsbyImageData: any;
    JSON: Record<string, unknown>;
};
export interface IStoryFragmentHooks {
    belief: Function;
    processRead: Function;
    updateEventStream: Function;
    GatsbyImage: Function;
    getImage: Function;
    navigate?: Function;
}
export interface IStoryFragment {
    id?: string | undefined;
    slug?: string | undefined;
    title?: string | undefined;
    tractStackId: string;
    tractStackSlug: string;
    tractStackTitle: string;
}
export interface IPaneFragmentBackgroundColour {
    id: string;
    field_background_colour: string;
    field_hidden_viewports: string;
    internal: {
        [key: string]: string;
    };
}
export interface IPaneFragmentBackgroundPane {
    id: string;
    field_zindex: number;
    field_shape: string;
    field_hidden_viewports: string;
    field_options: string;
    internal: {
        [key: string]: string;
    };
}
export interface IPaneFragmentBackgroundVideo {
    id: string;
    field_zindex: number;
    field_alt_text: string;
    field_image_mask_shape: string;
    field_hidden_viewports: string;
    field_cdn_url: string;
    field_options: string;
    internal: {
        [key: string]: string;
    };
}
export interface IPaneFragmentImageField {
    id: string;
    filename: string;
    childImageSharp: {
        gatsbyImageData: Scalars;
    };
}
export interface IPaneFragmentImageFieldDict {
    [key: string]: IPaneFragmentImageField;
}
export interface IPaneFragmentBackgroundImage {
    id: string;
    field_zindex: number;
    field_alt_text: string;
    field_image_mask_shape: string;
    field_hidden_viewports: string;
    field_options: string;
    field_background_position: string;
    internal: {
        [key: string]: string;
    };
    relationships: {
        field_image: IPaneFragmentImageFieldDict[];
    };
}
export interface IPaneFragmentSvg {
    id: string;
    field_zindex: number;
    field_image_mask_shape: string;
    field_hidden_viewports: string;
    field_options: string;
    field_svg_file: {
        description: string;
    };
    relationships: {
        field_svg_file: {
            id: string;
            filename: string;
            localFile: {
                publicURL: string;
            };
        };
    };
    internal: {
        [key: string]: string;
    };
}
export interface IPaneFragmentMarkdown {
    id: string;
    field_markdown_body: string;
    field_zindex: number;
    field_image_mask_shape: string;
    field_text_shape_outside: string;
    field_hidden_viewports: string;
    field_options: string;
    field_modal: boolean;
    field_context_pane: boolean;
    childPaneFragment: {
        childMarkdownRemark: {
            htmlAst: {
                children: object;
            };
        };
    };
    internal: {
        [key: string]: string;
    };
    relationships: {
        field_image: {
            id: string;
            filename: string;
            mobile: {
                localFile: {
                    childImageSharp: {
                        gatsbyImageData: Scalars;
                    };
                };
            };
            tablet: {
                localFile: {
                    childImageSharp: {
                        gatsbyImageData: Scalars;
                    };
                };
            };
            desktop: {
                localFile: {
                    childImageSharp: {
                        gatsbyImageData: Scalars;
                    };
                };
            };
        };
    };
}
export type IPaneFragment = IPaneFragmentBackgroundColour | IPaneFragmentBackgroundPane | IPaneFragmentBackgroundVideo | IPaneFragmentBackgroundImage | IPaneFragmentSvg | IPaneFragmentMarkdown;
export interface IPane {
    id: string;
    title: string;
    field_slug: string;
    field_options: object;
    field_height_ratio: string;
    field_height_offset: number;
    relationships: {
        field_pane_fragments: IPaneFragment;
    };
}
export interface ICompositorProps {
    panesPayload: IPane[];
    tailwindBgColour: string | null;
    viewportKey: string;
    hooks: IStoryFragmentHooks;
    id: IStoryFragment;
}
export interface IImpression {
    id: string;
    actionsLisp: string;
    body: string;
    buttonText: string;
    icon: string;
    parentId: string;
    title: string;
    weight: number;
}
export interface IImpressionDict {
    [key: string]: IImpression;
}
export interface IComposedStoryFragment {
    paneIds: string[];
    css: string;
    hasH5P: boolean;
    impressions: IImpressionDict;
}
export interface IComposedStoryFragmentDict {
    [key: string]: IComposedStoryFragment;
}
export interface ICodeHookIframe {
    target: string;
    url: string;
    height?: number;
    width?: number;
}
export interface ICodeHookShopify {
    id: string;
    target: string;
}
export interface ICodeHook {
    name: string;
    target: string;
}
export interface IContentMap {
    title: string;
    type: string;
    parentId: string;
    slug: string;
    heldBeliefs: any;
    tailwindBgColour?: string;
    hasCodeHook?: ICodeHook | ICodeHookIframe | ICodeHookShopify;
    hasMaxHScreen?: boolean;
}
export interface IContentMapDict {
    [key: string]: IContentMap;
}
export interface IContentChildrenDict {
    [key: string]: ReactFragment;
}
export {};
